searchData={"items":[{"type":"module","title":"Exbox","doc":"Exbox is a package containing common tooling and other functionality\nfor Zappi's Elixir/Phoenix applications.\nIt is the Elixir equivalent of the Opsbox, which was built for our Ruby/Rails stack.\nSupervisor for Exbox.\nthis exists to reduce the amount of boilerplate required to configure Exbox.\nAll GenServers, Supervisors and other processes for Exbox should be started from here.\nIt also has an entry point point for default opt-in by default functionality like attach_controller_metrics","ref":"Exbox.html"},{"type":"function","title":"Exbox.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Exbox.html#child_spec/1"},{"type":"function","title":"Exbox.init/1","doc":"Initialise the supervisor for Exbox. Set the children for the supervisor here.","ref":"Exbox.html#init/1"},{"type":"function","title":"Exbox.start_link/1","doc":"Start the supervisor for Exbox.","ref":"Exbox.html#start_link/1"},{"type":"module","title":"Exbox.Config","doc":"Exbox configuration module.\nAll configurations have a default value, which can be overridden in the application config.\nThe application config is keyed in the following way:\n```elixir\nconfig :exbox, :features, [\n  capture_telemetry_metric_events: true,\n  capture_telemetry_log_events: false\n]\n```","ref":"Exbox.Config.html"},{"type":"function","title":"Exbox.Config.capture_telemetry_log_events?/0","doc":"Returns the configuration for capture_telemetry_log_events","ref":"Exbox.Config.html#capture_telemetry_log_events?/0"},{"type":"function","title":"Exbox.Config.capture_telemetry_metric_events?/0","doc":"Returns the configuration for capture_telemetry_metric_events","ref":"Exbox.Config.html#capture_telemetry_metric_events?/0"},{"type":"function","title":"Exbox.Config.config_value/1","doc":"Returns the configuration value for the given key.","ref":"Exbox.Config.html#config_value/1"},{"type":"module","title":"Exbox.Flags","doc":"An Elixir wrapper around the LaunchDarkly Erlang client\n\nTo use this module you must have the LaunchDarkly Erlang client installed.\nTo do so, add {:ldclient, \"~> 2.0.0\", hex: :launchdarkly_server_sdk} to your\nlist of dependencies in mix.exs.\n\nTo start the client, call Exbox.Flags.start/2 when starting your application\nwith a map of config options and an optional tag:\n\n    iex> def start(_type, _args) do\n    iex>   Exbox.Flags.start(%{sdk_key: \"sdk-key\", private_attributes: [:email]})\n\nTo make sure that the client shuts down, you should call Exbox.Flags.stop/1\nwhen your application shuts down:\n\n    iex> def stop(_state) do\n    iex>   Exbox.Flags.stop()","ref":"Exbox.Flags.html"},{"type":"function","title":"Exbox.Flags.start/0","doc":"Starts the LaunchDarkly client with the given config and tag.\n\nExamples:\n\n      iex> Exbox.Flags.start(%{sdk_key: \"sdk-key\"}, :my_tag)\n      :ok\n\n      iex> Exbox.Flags.start(%{sdk_key: \"sdk-key\"}, :my_tag)\n      {:error, {:already_started, #PID }}","ref":"Exbox.Flags.html#start/0"},{"type":"function","title":"Exbox.Flags.start/1","doc":"Starts the LaunchDarkly client with the given config.","ref":"Exbox.Flags.html#start/1"},{"type":"function","title":"Exbox.Flags.start/2","doc":"Starts the LaunchDarkly client with the given config and tag.","ref":"Exbox.Flags.html#start/2"},{"type":"function","title":"Exbox.Flags.stop/0","doc":"Stops the ldclient with the default tag.","ref":"Exbox.Flags.html#stop/0"},{"type":"function","title":"Exbox.Flags.stop/1","doc":"Stops the ldclient with the given tag.","ref":"Exbox.Flags.html#stop/1"},{"type":"function","title":"Exbox.Flags.variation/3","doc":"Gets the variation of a flag for the given key, context, and default value.","ref":"Exbox.Flags.html#variation/3"},{"type":"function","title":"Exbox.Flags.variation/4","doc":"Gets the variation of a flag for the given key, context, default value, and tag.\n\nExamples:\n\n        iex> Exbox.Flags.variation(\"my-flag\", %{key: \"user-key\"}, false, :my_tag)\n        true\n\n        iex> Exbox.Flags.variation(\"my-flag\", %{key: \"user-key\"}, false, :my_tag)\n        {:error, {:not_found, \"my-flag\"}}","ref":"Exbox.Flags.html#variation/4"},{"type":"module","title":"Exbox.Logging","doc":"This module is responsible for attaching logging to telemetry events.\n\nTo use this module, you must have the Telemetry library installed.\nTo do so, add {:telemetry, \"~> 1.2.1\"} to your list of dependencies in mix.exs.","ref":"Exbox.Logging.html"},{"type":"function","title":"Exbox.Logging.attach_controller_logs/0","doc":"Attaches logging to the Phoenix endpoint stop and start events.\nBy default will be attached on supervisor startup","ref":"Exbox.Logging.html#attach_controller_logs/0"},{"type":"function","title":"Exbox.Logging.attach_telemetry/3","doc":"Attaches logging to the given event with the given params.","ref":"Exbox.Logging.html#attach_telemetry/3"},{"type":"function","title":"Examples - Exbox.Logging.attach_telemetry/3","doc":"","ref":"Exbox.Logging.html#attach_telemetry/3-examples"},{"type":"function","title":"Examples - Exbox.Logging.attach_telemetry/3","doc":"To attach metrics for a custom event `:my_event` with parameters `[:my, :event]`, and a custom handler function `my_handler/3`, you can do the following:\n\n```elixir\ndefmodule MyAppHandler do\n  def my_handler(event, measurements, metadata) do\n    # Your custom handler implementation here\n  end\nend\n\ndef start(_type, _args) do\n  Exbox.Logging.attach_telemetry(:my_event, [:my, :event], &MyAppHandler.my_handler/3)\nend\n```\nIn this example, when :my_event is triggered, the telemetry system will call MyAppHandler.my_handler/1 with the captured event data. Ensure that the handler function is implemented appropriately for your specific use case.\n\nNote: The logs will only be attached if the application environment variable :capture_telemetry_log_events is set to true.","ref":"Exbox.Logging.html#attach_telemetry/3-examples"},{"type":"function","title":"Parameters - Exbox.Logging.attach_telemetry/3","doc":"- `event` (binary()) - The name of the event to which metrics will be attached.\n  - `params` (list(atom())) - A list of parameters representing the context of the event.\n  - `function` (any(), any(), any(), any() -> any()) - The function to be called when the event occurs.\nReturns :ok if the logs are successfully attached.","ref":"Exbox.Logging.html#attach_telemetry/3-parameters"},{"type":"module","title":"Exbox.Logging.LogHandler","doc":"All log events are handled by this module.","ref":"Exbox.Logging.LogHandler.html"},{"type":"function","title":"Exbox.Logging.LogHandler.handle_event/4","doc":"This function is called by the Phoenix endpoint when a controller action is\nstarted and finished.\nThis allows us to use kibana for log inspection and monitoring\n\nExamples:\n\n    iex> Exbox.Logging.LogHandler.handle_event([:phoenix, :endpoint, :stop], measurements, metadata, config)\n    :ok","ref":"Exbox.Logging.LogHandler.html#handle_event/4"},{"type":"module","title":"Exbox.Metrics","doc":"A module for handling and standardising metrics in Exbox applications.\n\nTo use this module, you must have the Telemetry library installed.\nTo do so, add {:telemetry, \"~> 1.2.1\"} to your list of dependencies in mix.exs.\n\nIf you want to attach metrics to other events, you can use `Exbox.Metrics.attach_telemetry/3`:","ref":"Exbox.Metrics.html"},{"type":"module","title":"Examples - Exbox.Metrics","doc":"def start(_type, _args) do\n      Exbox.Metrics.attach_telemetry(:my_event, [:my, :params], &my_handler/1)\n    end","ref":"Exbox.Metrics.html#module-examples"},{"type":"module","title":"Public API - Exbox.Metrics","doc":"The following functions are provided by this module:\n\n- `attach_controller_metrics/0`: Attaches metrics to the Phoenix endpoint stop event.\n- `attach_telemetry/3`: Attaches metrics to the given event with the given params.","ref":"Exbox.Metrics.html#module-public-api"},{"type":"function","title":"Exbox.Metrics.attach_controller_metrics/0","doc":"Attaches metrics to the Phoenix endpoint stop event.","ref":"Exbox.Metrics.html#attach_controller_metrics/0"},{"type":"function","title":"Examples - Exbox.Metrics.attach_controller_metrics/0","doc":"iex> Exbox.Metrics.attach_controller_metrics()\n    :ok","ref":"Exbox.Metrics.html#attach_controller_metrics/0-examples"},{"type":"function","title":"Exbox.Metrics.attach_telemetry/3","doc":"Attaches metrics to the given event with the given params.","ref":"Exbox.Metrics.html#attach_telemetry/3"},{"type":"function","title":"Examples - Exbox.Metrics.attach_telemetry/3","doc":"To attach metrics for a custom event `:my_event` with parameters `[:my, :event]`, and a custom handler function `my_handler/3`, you can do the following:\n\n```elixir\ndefmodule MyAppHandler do\n  def my_handler(event, measurements, metadata) do\n    # Your custom handler implementation here\n  end\nend\n\ndef start(_type, _args) do\n  Exbox.Metrics.attach_telemetry(:my_event, [:my, :event], &MyAppHandler.my_handler/3)\nend\n```\nIn this example, when :my_event is triggered, the telemetry system will call MyAppHandler.my_handler/1 with the captured event data. Ensure that the handler function is implemented appropriately for your specific use case.\n\nNote: The metrics will only be attached if the application environment variable :capture_telemetry_events is set to true.","ref":"Exbox.Metrics.html#attach_telemetry/3-examples"},{"type":"function","title":"Parameters - Exbox.Metrics.attach_telemetry/3","doc":"- `event` (binary()) - The name of the event to which metrics will be attached.\n  - `params` (list(atom())) - A list of parameters representing the context of the event.\n  - `function` (any(), any(), any(), any() -> any()) - The function to be called when the event occurs.\nReturns :ok if the metrics are successfully attached.","ref":"Exbox.Metrics.html#attach_telemetry/3-parameters"},{"type":"module","title":"Exbox.Metrics.Client","doc":"A client module for writing metrics to InfluxDB.","ref":"Exbox.Metrics.Client.html"},{"type":"module","title":"Overview - Exbox.Metrics.Client","doc":"This module provides functions to write metrics to InfluxDB, a time-series database that allows for efficient storage and querying of data with a timestamp.\n\nTo use this module, you need to have the `Exbox.Metrics.Connection` application running. Make sure to start it as an application in your supervision tree:\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    {Exbox.Metrics.Connection, []}\n  ]\n  Supervisor.start_link(children, strategy: :one_for_one)\nend\n```","ref":"Exbox.Metrics.Client.html#module-overview"},{"type":"module","title":"Writing Metrics - Exbox.Metrics.Client","doc":"The main function provided by this module is write_metric/1. It accepts a metric data structure and writes it to InfluxDB.","ref":"Exbox.Metrics.Client.html#module-writing-metrics"},{"type":"module","title":"Examples - Exbox.Metrics.Client","doc":"","ref":"Exbox.Metrics.Client.html#module-examples"},{"type":"module","title":"Writing Custom metrics - Exbox.Metrics.Client","doc":"```elixir\n  iex> metric = %Exbox.Metrics.Series.Generic{\n  ...>   measurement: \"my_measurement\",\n  ...>   fields: %{\n  ...>     \"my_field\" => 1\n  ...>   },\n  ...>   tags: %{\n  ...>     \"my_tag\" => \"my_value\"\n  ...>   }\n  ...> }\n  iex> Exbox.Metrics.Client.write_metric(metric)\n  {:ok, %Exbox.Metrics.Series.Generic{\n    measurement: \"my_measurement\",\n    fields: %{\n      \"my_field\" => 1\n    },\n    tags: %{\n      \"my_tag\" => \"my_value\"\n    }\n  }}\n  ```\n\n  #","ref":"Exbox.Metrics.Client.html#module-writing-custom-metrics"},{"type":"module","title":"Error Handling - Exbox.Metrics.Client","doc":"If there is an error while writing the metric, the function will log the error using the Logger module. without crashing the process","ref":"Exbox.Metrics.Client.html#module-error-handling"},{"type":"function","title":"Exbox.Metrics.Client.write_metric/1","doc":"Write a metric to InfluxDB.\n\nExamples:\n\n    iex> Exbox.Metrics.Client.write_metric(%ControllerSeries{})\n    {:ok, %ControllerSeries{}}","ref":"Exbox.Metrics.Client.html#write_metric/1"},{"type":"type","title":"Exbox.Metrics.Client.series/0","doc":"","ref":"Exbox.Metrics.Client.html#t:series/0"},{"type":"module","title":"Exbox.Metrics.Connection","doc":"Connection for writing metrics to InfluxDB.","ref":"Exbox.Metrics.Connection.html"},{"type":"module","title":"Exbox.Metrics.ControllerSeries","doc":"This module defines generic controller metrics.\n\nThe fields captured are:\n\n* duration_ms - The time taken to process the request in milliseconds\n* success - Whether the request was successful (1.0) or not (0.0)\n* path - The path of the request\n* http_referer - The referer of the request\n* count - The number of requests\n* request_id - The request ID of the request\n\nThe tags allowed are:\n\n* controller - The name of the controller\n* action - The name of the action\n* method - The HTTP method of the request\n* format - The format of the request\n* status - The status of the request","ref":"Exbox.Metrics.ControllerSeries.html"},{"type":"function","title":"Exbox.Metrics.ControllerSeries.field/3","doc":"Adds a field to the series","ref":"Exbox.Metrics.ControllerSeries.html#field/3"},{"type":"function","title":"Exbox.Metrics.ControllerSeries.tag/3","doc":"Adds a tag to the series","ref":"Exbox.Metrics.ControllerSeries.html#tag/3"},{"type":"type","title":"Exbox.Metrics.ControllerSeries.t/0","doc":"","ref":"Exbox.Metrics.ControllerSeries.html#t:t/0"},{"type":"module","title":"Exbox.Metrics.MetricHandler","doc":"This module is responsible for logging controller metrics to influx","ref":"Exbox.Metrics.MetricHandler.html"},{"type":"function","title":"Exbox.Metrics.MetricHandler.handle_event/4","doc":"This function is called by the Phoenix endpoint when a controller action is\nfinished. It will log the controller metrics to influx.\n\nExamples:\n\n    iex> Exbox.Metrics.MetricHandler.handle_event([:phoenix, :endpoint, :stop], measurements, metadata, config)\n    :ok","ref":"Exbox.Metrics.MetricHandler.html#handle_event/4"},{"type":"module","title":"Exbox.Metrics.Series","doc":"This module defines a simple struct to write metrics to InfluxDB.\nthe attributes are:\n* measurement - The name of the measurement\n* fields - The fields of the measurement, these are the values you want to aggregate on\n* tags - The tags of the measurement, these are usually identifiers for the values but you can't aggregate on them\n* timestamp - The timestamp of the measurement, it is optional, if it's missing in the struct, InfluxDB will use the current time","ref":"Exbox.Metrics.Series.html"},{"type":"type","title":"Exbox.Metrics.Series.t/0","doc":"","ref":"Exbox.Metrics.Series.html#t:t/0"},{"type":"task","title":"mix bump","doc":"Bump version number in mix.exs and create a new git tag.","ref":"Mix.Tasks.Bump.html"},{"type":"function","title":"Mix.Tasks.Bump.run/1","doc":"Runs the task with the given arguments.","ref":"Mix.Tasks.Bump.html#run/1"}],"content_type":"text/markdown"}